@@ -290,7 +290,7 @@ class PyCytoData():
             indices = indices[indices_temp]
             
         if bead_normalization:
-            _verbose("Runinng bead normalization...", verbose=verbose)
+            _verbose("Running bead normalization...", verbose=verbose)
             assert bead_channels is not None
             assert time_channel is not None
             assert self.lineage_channels is not None
@@ -458,6 +458,19 @@ class PyCytoData():
     
     
     def __iadd__(self, new_object: PyCytoData) -> PyCytoData:
+        """Concatenate a new `PyCytoData` object with the `+=` operator.
+
+        This essentially works the same way the ``add_sample`` method. However,
+        instead of the necessity of providing the expression matrices, sample
+        indices, and the cell types manually, the concatenation is automatically
+        performed from a new `PyCytoData` object.
+
+        :param new_object: The second `PyCytoData` object.
+        :type new_object: PyCytoData
+        :raises TypeError: The provided object is not a `PyCytoData` object.
+        :return: A new `PyCytoData` object after concatenation.
+        :rtype: PyCytoData
+        """
         if not isinstance(new_object, PyCytoData):
             raise TypeError("The right hand side has to be a 'PyCytoData' object.")
         self.add_sample(new_object.expression_matrix, sample_index=new_object.sample_index, cell_types=new_object.cell_types)
@@ -465,6 +478,17 @@ class PyCytoData():
     
     
     def __add__(self, new_object: PyCytoData) -> PyCytoData:
+        """Concatenate two `PyCytoData` objects with the `+` operator.
+
+        This method concatenates two `PyCytOData` objects together by using
+        the `add_sample` method internally. A new `PyCytoData` object is returned.
+
+        :param new_object: The second `PyCytoData` object.
+        :type new_object: PyCytoData
+        :raises TypeError: The provided object is not a `PyCytoData` object.
+        :return: A new `PyCytoData` object after concatenation.
+        :rtype: PyCytoData
+        """
         if not isinstance(new_object, PyCytoData):
             raise TypeError("The right hand side has to be a 'PyCytoData' object.")
         out_object = deepcopy(self)
@@ -798,10 +822,7 @@ class DataLoader():
     _data_path: Dict[str, str] = {"levine13": _data_dir + "levine13/",
                                   "levine32": _data_dir + "levine32/",
                                   "samusik": _data_dir + "samusik/"}
-    # Check data status
-    _data_status: Dict[str, bool] = {}
-    for d in _data_path.keys():
-        _data_status[d] = os.path.exists(_data_path[d])
+
 
     @classmethod    
     def load_dataset(cls, dataset: str, sample: Optional[ArrayLike]=None, force_download: bool = False, preprocess: bool=False) -> PyCytoData:
@@ -838,14 +859,15 @@ class DataLoader():
         dataset = dataset.lower()
         if dataset not in ["levine13", "levine32", "samusik"]:
             raise ValueError("Unsupported dataset: Have to be 'levine13', 'levine32', or 'samusik'.")
-        
-        if not cls._data_status[dataset]:
+                
+        if not os.path.exists(cls._data_path[dataset]):
             cls._download_data(dataset = dataset, force_download = force_download)
             
         if sample is not None and not isinstance(sample, np.ndarray):
             sample = np.array(sample).flatten()
             
         all_files = glob.glob(cls._data_path[dataset]+dataset+"*.txt")
+        all_files = sorted(all_files)
         files: List[str] = []
         metadata_files: List[str] = []
         for f in all_files:
@@ -857,7 +879,7 @@ class DataLoader():
         if sample is not None:
             r = re.compile("(.*" + ".*)|(.*".join(sample) + ".*)")
             files = list(filter(r.match, files))
-            metadata_files = list(filter(r.match, metadata_files))         
+            metadata_files = list(filter(r.match, metadata_files))   
             
         data: PyCytoData = FileIO.load_expression(files=files, col_names = True)
         metadata: Optional[np.ndarray] = None
